@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 The SeleniumBase-Behave Connector configures command-line options.
 ******************************************************************
@@ -8,12 +7,12 @@ behave -D rs -D dashboard
 behave -D agent="User Agent String" -D demo
 ****************************************************************
 -D browser=BROWSER  (The web browser to use. Default: "chrome".)
--D chrome  (Shortcut for "-D browser=chrome". On by default.)
+-D chrome  (Shortcut for "-D browser=chrome". Default.)
 -D edge  (Shortcut for "-D browser=edge".)
 -D firefox  (Shortcut for "-D browser=firefox".)
--D ie  (Shortcut for "-D browser=ie".)
--D opera  (Shortcut for "-D browser=opera".)
 -D safari  (Shortcut for "-D browser=safari".)
+-D cft  (Shortcut for using `Chrome for Testing`)
+-D chs  (Shortcut for using `Chrome-Headless-Shell`)
 -D settings-file=FILE  (Override default SeleniumBase settings.)
 -D env=ENV  (Set the test env. Access with "self.env" in tests.)
 -D account=STR  (Set account. Access with "self.account" in tests.)
@@ -28,11 +27,12 @@ behave -D agent="User Agent String" -D demo
 -D port=PORT  (The Selenium Grid port used by the test server.)
 -D cap-file=FILE  (The web browser's desired capabilities to use.)
 -D cap-string=STRING  (The web browser's desired capabilities to use.)
--D proxy=SERVER:PORT  (Connect to a proxy server:port for tests.)
--D proxy=USERNAME:PASSWORD@SERVER:PORT  (Use authenticated proxy server.)
+-D proxy=SERVER:PORT  (Connect to a proxy server:port as tests are running)
+-D proxy=USERNAME:PASSWORD@SERVER:PORT  (Use an authenticated proxy server)
 -D proxy-bypass-list=STRING (";"-separated hosts to bypass, Eg "*.foo.com")
 -D proxy-pac-url=URL  (Connect to a proxy server using a PAC_URL.pac file.)
 -D proxy-pac-url=USERNAME:PASSWORD@URL  (Authenticated proxy with PAC URL.)
+-D multi-proxy  (Allow multiple authenticated proxies when multi-threaded.)
 -D agent=STRING  (Modify the web browser's User-Agent string.)
 -D mobile  (Use the mobile device emulator while running tests.)
 -D metrics=STRING  (Set mobile metrics: "CSSWidth,CSSHeight,PixelRatio".)
@@ -41,9 +41,17 @@ behave -D agent="User Agent String" -D demo
 -D firefox-pref=SET  (Set a Firefox preference:value set, comma-separated.)
 -D extension-zip=ZIP  (Load a Chrome Extension .zip|.crx, comma-separated.)
 -D extension-dir=DIR  (Load a Chrome Extension directory, comma-separated.)
--D headless  (Run tests in headless mode. The default arg on Linux OS.)
--D headed  (Run tests in headed/GUI mode on Linux OS.)
+-D binary-location=PATH  (Set path of the Chromium browser binary to use.)
+-D driver-version=VER  (Set the chromedriver or uc_driver version to use.)
+-D sjw  (Skip JS Waits for readyState to be "complete" or Angular to load.)
+-D wfa  (Wait for AngularJS to be done loading after specific web actions.)
+-D pls=PLS  (Set pageLoadStrategy on Chrome: "normal", "eager", or "none".)
+-D headless  (The default headless mode. Linux uses this mode by default.)
+-D headless1  (Use Chrome's old headless mode. Fast, but has limitations.)
+-D headless2  (Use Chrome's new headless mode, which supports extensions.)
+-D headed  (Run tests in headed/GUI mode on Linux OS, where not default.)
 -D xvfb  (Run tests using the Xvfb virtual display server on Linux OS.)
+-D xvfb-metrics=STRING  (Set Xvfb display size on Linux: "Width,Height".)
 -D locale=LOCALE_CODE  (Set the Language Locale Code for the web browser.)
 -D pdb  (Activate Post Mortem Debug Mode if a test fails.)
 -D interval=SECONDS  (The autoplay interval for presentations & tour steps)
@@ -65,44 +73,56 @@ behave -D agent="User Agent String" -D demo
 -D rec-behave  (Same as Recorder Mode, but also generates behave-gherkin.)
 -D rec-sleep  (If the Recorder is enabled, also records self.sleep calls.)
 -D rec-print  (If the Recorder is enabled, prints output after tests end.)
+-D disable-cookies  (Disable Cookies on websites. Pages might break!)
+-D disable-js  (Disable JavaScript on websites. Pages might break!)
 -D disable-csp  (Disable the Content Security Policy of websites.)
 -D disable-ws  (Disable Web Security on Chromium-based browsers.)
 -D enable-ws  (Enable Web Security on Chromium-based browsers.)
 -D enable-sync  (Enable "Chrome Sync".)
--D use-auto-ext  (Use Chrome's automation extension.)
--D remote-debug  (Enable Chrome's Remote Debugger on http://localhost:9222)
+-D uc | -D undetected  (Use undetected-chromedriver to evade bot-detection)
+-D uc-cdp-events  (Capture CDP events when running in "-D undetected" mode)
+-D log-cdp  ("goog:loggingPrefs", {"performance": "ALL", "browser": "ALL"})
+-D remote-debug  (Sync to Chrome Remote Debugger chrome://inspect/#devices)
 -D dashboard  (Enable the SeleniumBase Dashboard. Saved at: dashboard.html)
 -D dash-title=STRING  (Set the title shown for the generated dashboard.)
--D swiftshader  (Use Chrome's "--use-gl=swiftshader" feature.)
+-D enable-3d-apis  (Enables WebGL and 3D APIs.)
+-D swiftshader  (Use Chrome's SwiftShader Graphics Library.)
 -D incognito  (Enable Chrome's Incognito mode.)
 -D guest  (Enable Chrome's Guest mode.)
+-D dark  (Enable Chrome's Dark mode.)
 -D devtools  (Open Chrome's DevTools when the browser opens.)
--D reuse-session | -D rs  (Reuse browser session between tests.)
+-D rs | -D reuse-session  (Reuse browser session for all tests.)
+-D rcs | -D reuse-class-session  (Reuse session for tests in class/feature)
 -D crumbs  (Delete all cookies between tests reusing a session.)
--D window-size  (Set the browser window size: "Width,Height".)
+-D disable-beforeunload  (Disable the "beforeunload" event on Chrome.)
+-D window-position=X,Y  (Set the browser's starting window position.)
+-D window-size=WIDTH,HEIGHT  (Set the browser's starting window size.)
 -D maximize  (Start tests with the browser window maximized.)
 -D screenshot  (Save a screenshot at the end of each test.)
+-D no-screenshot  (No screenshots saved unless tests directly ask it.)
 -D visual-baseline  (Set the visual baseline for Visual/Layout tests.)
--D external-pdf (Set Chromium "plugins.always_open_pdf_externally": True.)
+-D wire  (Use selenium-wire's webdriver for replacing selenium webdriver.)
+-D external-pdf  (Set Chromium "plugins.always_open_pdf_externally":True.)
 -D timeout-multiplier=MULTIPLIER  (Multiplies the default timeout values.)
 """
-
 import ast
 import colorama
 import os
 import re
 import sys
-from seleniumbase.config import settings
-from seleniumbase.core import log_helper
-from seleniumbase.core import download_helper
-from seleniumbase.core import proxy_helper
-from seleniumbase.fixtures import constants
+from contextlib import suppress
 from seleniumbase import config as sb_config
+from seleniumbase.config import settings
+from seleniumbase.core import download_helper
+from seleniumbase.core import log_helper
+from seleniumbase.core import proxy_helper
+from seleniumbase.core import session_helper
+from seleniumbase.fixtures import constants
+from seleniumbase.fixtures import shared_utils
 
+is_linux = shared_utils.is_linux()
+is_windows = shared_utils.is_windows()
 sb_config.__base_class = None
-is_windows = False
-if sys.platform in ["win32", "win64", "x64"]:
-    is_windows = True
 
 
 def set_base_class(base_class):
@@ -128,8 +148,12 @@ def get_configured_sb(context):
     sb.browser = "chrome"
     sb.is_behave = True
     sb.headless = False
+    sb.headless1 = False
+    sb.headless2 = False
+    sb.headless_active = False
     sb.headed = False
     sb.xvfb = False
+    sb.xvfb_metrics = None
     sb.start_page = None
     sb.locale_code = None
     sb.pdb_option = False
@@ -143,31 +167,49 @@ def get_configured_sb(context):
     sb.variables = {}
     sb.account = None
     sb.environment = "test"
+    sb.env = "test"
     sb.user_agent = None
     sb.incognito = False
     sb.guest_mode = False
+    sb.dark_mode = False
     sb.devtools = False
     sb.mobile_emulator = False
     sb.device_metrics = None
     sb.extension_zip = None
     sb.extension_dir = None
+    sb.binary_location = None
+    sb_config.binary_location = None
+    sb.driver_version = None
+    sb.page_load_strategy = None
     sb.database_env = "test"
-    sb.log_path = "latest_logs/"
+    sb.log_path = constants.Logs.LATEST + os.sep
     sb.archive_logs = False
+    sb.disable_cookies = False
+    sb.disable_js = False
     sb.disable_csp = False
     sb.disable_ws = False
     sb.enable_ws = False
     sb.enable_sync = False
     sb.use_auto_ext = False
+    sb.undetectable = False
+    sb.uc_cdp_events = False
+    sb.uc_subprocess = False
+    sb.log_cdp_events = False
     sb.no_sandbox = False
     sb.disable_gpu = False
     sb._multithreaded = False
     sb._reuse_session = False
+    sb._reuse_class_session = False
     sb._crumbs = False
+    sb._disable_beforeunload = False
     sb.visual_baseline = False
+    sb.use_wire = False
+    sb.window_position = None
     sb.window_size = None
     sb.maximize_option = False
+    sb.is_context_manager = False
     sb.save_screenshot_after_test = False
+    sb.no_screenshot_after_test = False
     sb.timeout_multiplier = None
     sb.pytest_html_report = None
     sb.with_db_reporting = False
@@ -197,11 +239,16 @@ def get_configured_sb(context):
     sb.chromium_arg = None
     sb.firefox_arg = None
     sb.firefox_pref = None
+    sb.disable_features = None
     sb.proxy_string = None
     sb.proxy_bypass_list = None
     sb.proxy_pac_url = None
+    sb.multi_proxy = False
+    sb.host_resolver_rules = None
+    sb.enable_3d_apis = False
     sb.swiftshader = False
     sb.ad_block_on = False
+    sb.is_nosetest = False
     sb.highlights = None
     sb.interval = None
     sb.cap_file = None
@@ -209,8 +256,10 @@ def get_configured_sb(context):
 
     # Set a few sb_config vars early in case parsing args fails
     sb_config.dashboard = None
+    sb_config._has_logs = None
     sb_config._has_exception = None
     sb_config.save_screenshot = None
+    sb_config.reuse_class_session = None
 
     browsers = set()  # To error if selecting more than one
     valid_browsers = constants.ValidBrowsers.valid_browsers
@@ -253,6 +302,15 @@ def get_configured_sb(context):
         if low_key == "headless":
             sb.headless = True
             continue
+        # Handle: -D headless2
+        if low_key == "headless1":
+            sb.headless1 = True
+            sb.headless = True
+            continue
+        # Handle: -D headless2
+        if low_key == "headless2":
+            sb.headless2 = True
+            continue
         # Handle: -D headed / gui
         if low_key in ["headed", "gui"]:
             sb.headed = True
@@ -261,6 +319,13 @@ def get_configured_sb(context):
         if low_key == "xvfb":
             sb.xvfb = True
             continue
+        # Handle: -D xvfb-metrics=STR / xvfb_metrics=STR
+        if low_key in ["xvfb-metrics", "xvfb_metrics"]:
+            xvfb_metrics = userdata[key]
+            if xvfb_metrics == "true":
+                xvfb_metrics = sb.xvfb_metrics  # revert to default
+            sb.xvfb_metrics = xvfb_metrics
+            continue
         # Handle: -D start-page=URL / start_page=URL / url=URL
         if low_key in ["start-page", "start_page", "url"]:
             start_page = userdata[key]
@@ -327,7 +392,7 @@ def get_configured_sb(context):
         # Handle: -D variables="{'KEY':'VALUE','KEY2':'VALUE2'}"
         if low_key == "variables":
             variables = userdata[key]
-            if variables and type(variables) is str and len(variables) > 0:
+            if variables and isinstance(variables, str) and len(variables) > 0:
                 bad_input = False
                 if (
                     not variables.startswith("{")
@@ -337,7 +402,7 @@ def get_configured_sb(context):
                 else:
                     try:
                         variables = ast.literal_eval(variables)
-                        if not type(variables) is dict:
+                        if not isinstance(variables, dict):
                             bad_input = True
                     except Exception:
                         bad_input = True
@@ -358,6 +423,7 @@ def get_configured_sb(context):
             environment = userdata[key].lower()
             if environment in valid_envs:
                 sb.environment = environment
+                sb.env = environment
             elif environment == "true":
                 raise Exception(
                     '\nThe "env" argument requires a value!'
@@ -386,6 +452,10 @@ def get_configured_sb(context):
         if low_key in ["guest", "guest-mode", "guest_mode"]:
             sb.guest_mode = True
             continue
+        # Handle: -D dark / dark-mode / dark_mode
+        if low_key in ["dark", "dark-mode", "dark_mode"]:
+            sb.dark_mode = True
+            continue
         # Handle: -D devtools / open-devtools / open_devtools
         if low_key in ["devtools", "open-devtools", "open_devtools"]:
             sb.devtools = True
@@ -415,6 +485,51 @@ def get_configured_sb(context):
                 extension_dir = sb.extension_dir  # revert to default
             sb.extension_dir = extension_dir
             continue
+        # Handle: -D binary-location=PATH / binary_location=PATH / bl=PATH
+        if low_key in ["binary-location", "binary_location", "bl"]:
+            binary_location = userdata[key]
+            if binary_location == "true":
+                binary_location = sb.binary_location  # revert to default
+            sb.binary_location = binary_location
+            sb_config.binary_location = binary_location
+            continue
+        # Handle: -D cft
+        if low_key in ["cft"] and not sb_config.binary_location:
+            binary_location = "cft"
+            sb.binary_location = binary_location
+            sb_config.binary_location = binary_location
+            continue
+        # Handle: -D chs
+        if low_key in ["chs"] and not sb_config.binary_location:
+            binary_location = "chs"
+            sb.binary_location = binary_location
+            sb_config.binary_location = binary_location
+            continue
+        # Handle: -D driver-version=VER / driver_version=VER
+        if low_key in ["driver-version", "driver_version"]:
+            driver_version = userdata[key]
+            if driver_version == "true":
+                driver_version = sb.driver_version  # revert to default
+            sb.driver_version = driver_version
+            continue
+        # Handle: -D pls=PLS / page-load-strategy=PLS / page_load_strategy=PLS
+        if low_key in ["pls", "page-load-strategy", "page_load_strategy"]:
+            page_load_strategy = userdata[key].lower()
+            if page_load_strategy in ["normal", "eager", "none"]:
+                sb.page_load_strategy = page_load_strategy
+            elif page_load_strategy == "true":
+                raise Exception(
+                    '\nThe "pls" / "page-load-strategy" arg requires a value!'
+                    '\nChoose from ["normal", "eager", "none"]'
+                    '\nEg. -D pls="none"'
+                )
+            else:
+                raise Exception(
+                    '\n"%s" is not a valid "pls" / "page-load-strategy" value!'
+                    '\nChoose from ["normal", "eager", "none"]'
+                    '\nEg. -D pls="none"' % page_load_strategy
+                )
+            continue
         # Handle: -D database-env=ENVIRONMENT / database_env=ENVIRONMENT
         if low_key in ["database-env", "database_env"]:
             database_env = userdata[key].lower()
@@ -438,12 +553,20 @@ def get_configured_sb(context):
         if low_key in ["archive-logs", "archive_logs"]:
             sb.archive_logs = True
             continue
-        # Handle: -D disable-csp / disable_csp
-        if low_key in ["disable-csp", "disable_csp"]:
+        # Handle: -D disable-cookies / disable_cookies
+        if low_key in ["disable-cookies", "disable_cookies"]:
+            sb.disable_cookies = True
+            continue
+        # Handle: -D disable-js / disable_js
+        if low_key in ["disable-js", "disable_js"]:
+            sb.disable_js = True
+            continue
+        # Handle: -D disable-csp / disable_csp / dcsp
+        if low_key in ["disable-csp", "disable_csp", "dcsp"]:
             sb.disable_csp = True
             continue
-        # Handle: -D disable-ws / disable_ws
-        if low_key in ["disable-ws", "disable_ws"]:
+        # Handle: -D disable-ws / disable_ws / dws
+        if low_key in ["disable-ws", "disable_ws", "dws"]:
             sb.disable_ws = True
             continue
         # Handle: -D enable-ws / enable_ws
@@ -458,6 +581,24 @@ def get_configured_sb(context):
         if low_key in ["use-auto-ext", "use_auto_ext", "auto-ext"]:
             sb.use_auto_ext = True
             continue
+        # Handle: -D undetected / undetectable / uc
+        if low_key in ["undetected", "undetectable", "uc"]:
+            sb.undetectable = True
+            continue
+        # Handle: -D uc-cdp-events / uc_cdp_events / uc-cdp
+        if low_key in ["uc-cdp-events", "uc_cdp_events", "uc-cdp"]:
+            sb.uc_cdp_events = True
+            sb.undetectable = True
+            continue
+        # Handle: -D uc-subprocess / uc_subprocess / uc-sub
+        if low_key in ["uc-subprocess", "uc_subprocess", "uc-sub"]:
+            sb.uc_subprocess = True
+            sb.undetectable = True
+            continue
+        # Handle: -D log-cdp-events / log_cdp_events / log-cdp
+        if low_key in ["log-cdp-events", "log_cdp_events", "log-cdp"]:
+            sb.log_cdp_events = True
+            continue
         # Handle: -D no-sandbox / no_sandbox
         if low_key in ["no-sandbox", "no_sandbox"]:
             sb.no_sandbox = True
@@ -470,14 +611,44 @@ def get_configured_sb(context):
         if low_key in ["rs", "reuse-session", "reuse_session"]:
             sb._reuse_session = True
             continue
+        # Handle: -D rcs / rfs / reuse-class-session / reuse-feature-session
+        if low_key in [
+            "rcs", "rfs", "reuse-class-session", "reuse-feature-session"
+        ]:
+            sb._reuse_session = True
+            sb._reuse_class_session = True
+            continue
         # Handle: -D crumbs
         if low_key == "crumbs":
             sb._crumbs = True
             continue
+        # Handle: -D disable-beforeunload / disable_beforeunload
+        if low_key in ["disable-beforeunload", "disable_beforeunload"]:
+            sb._disable_beforeunload = True
+            continue
+        # Handle: -D sjw / skip-js-waits / skip_js_waits
+        if low_key in ["sjw", "skip-js-waits", "skip_js_waits"]:
+            settings.SKIP_JS_WAITS = True
+            continue
+        # Handle: -D wfa / wait-for-angularjs / wait_for_angularjs
+        if low_key in ["wfa", "wait-for-angularjs", "wait_for_angularjs"]:
+            settings.WAIT_FOR_ANGULARJS = True
+            continue
         # Handle: -D visual-baseline / visual_baseline
         if low_key in ["visual-baseline", "visual_baseline"]:
             sb.visual_baseline = True
             continue
+        # Handle: -D wire
+        if low_key == "wire":
+            sb.use_wire = True
+            continue
+        # Handle: -D window-position=X,Y / window_position=X,Y
+        if low_key in ["window-position", "window_position"]:
+            window_position = userdata[key]
+            if window_position == "true":
+                window_position = sb.window_position  # revert to default
+            sb.window_position = window_position
+            continue
         # Handle: -D window-size=Width,Height / window_size=Width,Height
         if low_key in ["window-size", "window_size"]:
             window_size = userdata[key]
@@ -497,6 +668,10 @@ def get_configured_sb(context):
         ]:
             sb.save_screenshot_after_test = True
             continue
+        # Handle: -D no-screenshot / no_screenshot / ns
+        if low_key in ["no-screenshot", "no_screenshot", "ns"]:
+            sb.no_screenshot_after_test = True
+            continue
         # Handle: -D timeout-multiplier=FLOAT / timeout_multiplier=FLOAT
         if low_key in ["timeout-multiplier", "timeout_multiplier"]:
             timeout_multiplier = userdata[key]
@@ -588,8 +763,8 @@ def get_configured_sb(context):
         if low_key in ["external-pdf", "external_pdf"]:
             sb.external_pdf = True
             continue
-        # Handle: -D remote-debug / remote_debug
-        if low_key in ["remote-debug", "remote_debug"]:
+        # Handle: -D remote-debug / remote_debug / remote-debugger
+        if low_key in ["remote-debug", "remote_debug", "remote-debugger"]:
             sb.remote_debug = True
             continue
         # Handle: -D settings=FILE / settings-file=FILE / settings_file=FILE
@@ -627,6 +802,13 @@ def get_configured_sb(context):
                 firefox_pref = sb.firefox_pref  # revert to default
             sb.firefox_pref = firefox_pref
             continue
+        # Handle: -D disable-features="F1,F2" / disable_features="F1,F2"
+        if low_key in ["disable-features", "disable_features"]:
+            disable_features = userdata[key]
+            if disable_features == "true":
+                disable_features = sb.disable_features  # revert to default
+            sb.disable_features = disable_features
+            continue
         # Handle: -D proxy=SERVER:PORT / proxy=USERNAME:PASSWORD@SERVER:PORT
         if low_key in ["proxy", "proxy-server", "proxy-string"]:
             proxy_string = userdata[key]
@@ -648,6 +830,21 @@ def get_configured_sb(context):
                 proxy_pac_url = sb.proxy_pac_url  # revert to default
             sb.proxy_pac_url = proxy_pac_url
             continue
+        # Handle: -D multi-proxy / multi_proxy
+        if low_key in ["multi-proxy", "multi_proxy"]:
+            sb.multi_proxy = True
+            continue
+        # Handle: -D host-resolver-rules=RULES / host_resolver_rules=RULES
+        if low_key in ["host-resolver-rules", "host_resolver_rules"]:
+            host_resolver_rules = userdata[key]
+            if host_resolver_rules == "true":
+                host_resolver_rules = sb.host_resolver_rules
+            sb.host_resolver_rules = host_resolver_rules
+            continue
+        # Handle: -D enable-3d-apis / enable_3d_apis
+        if low_key in ["enable-3d-apis", "enable_3d_apis"]:
+            sb.enable_3d_apis = True
+            continue
         # Handle: -D swiftshader
         if low_key == "swiftshader":
             sb.swiftshader = True
@@ -693,13 +890,24 @@ def get_configured_sb(context):
             "\nOnly ONE default browser is allowed!\n"
             "%s browsers were selected: %s" % (len(browsers), browsers)
         )
-    # Recorder Mode does not support headless browser runs.
-    # Chromium does not allow extensions in Headless Mode.
+    # Recorder Mode can still optimize scripts in "-D headless2" mode.
     if sb.recorder_ext and sb.headless:
-        raise Exception(
-            "\n\n  Recorder Mode does NOT support Headless Mode!"
-            '\n  (DO NOT combine "-D rec" with "-D headless"!)\n'
-        )
+        sb.headless = False
+        sb.headless1 = False
+        sb.headless2 = True
+    if sb.headless2 and sb.browser == "firefox":
+        sb.headless2 = False  # Only for Chromium browsers
+        sb.headless = True  # Firefox has regular headless
+    elif sb.browser not in ["chrome", "edge"]:
+        sb.headless2 = False  # Only for Chromium browsers
+    if (
+        sb.binary_location
+        and sb.binary_location.lower() == "chs"
+        and sb.browser == "chrome"
+    ):
+        sb.headless = True
+        sb.headless1 = False
+        sb.headless2 = False
     # Recorder Mode only supports Chromium browsers.
     if sb.recorder_ext and (sb.browser not in ["chrome", "edge"]):
         raise Exception(
@@ -707,29 +915,77 @@ def get_configured_sb(context):
             '\n  (Your browser choice was: "%s")\n' % sb.browser
         )
     # The Xvfb virtual display server is for Linux OS Only.
-    if sb.xvfb and "linux" not in sys.platform:
+    if sb.xvfb and not is_linux:
         sb.xvfb = False
     if (
-        "linux" in sys.platform
+        is_linux
         and not sb.headed
         and not sb.headless
+        and not sb.headless2
         and not sb.xvfb
     ):
-        print(
-            '(Linux uses "-D headless" by default. '
-            'To override, use "-D headed" / "-D gui". '
-            'For Xvfb mode instead, use "-D xvfb". '
-            'Or hide this info with "-D headless".)'
-        )
-        sb.headless = True
-    if not sb.headless:
+        if not sb.undetectable:
+            print(
+                '(Linux uses "-D headless" by default. '
+                'To override, use "-D headed" / "-D gui". '
+                'For Xvfb mode instead, use "-D xvfb". '
+                "Or you can hide this info by using"
+                '"-D headless" / "-D headless2" / "-D uc".)'
+            )
+            sb.headless = True
+        else:
+            sb.xvfb = True
+    # Recorder Mode can still optimize scripts in --headless2 mode.
+    if sb.recorder_mode and sb.headless:
+        sb.headless = False
+        sb.headless1 = False
+        sb.headless2 = True
+    if not sb.headless and not sb.headless2:
         sb.headed = True
+    if sb.browser == "safari" and sb.headless:
+        sb.headless = False  # Safari doesn't support headless mode
+        sb.headless1 = False
+    if sb.save_screenshot_after_test and sb.no_screenshot_after_test:
+        sb.save_screenshot_after_test = False  # "no_screenshot" has priority
     if sb.servername != "localhost":
         # Using Selenium Grid
         # (Set -D server="127.0.0.1" for localhost Grid)
         # If the port is "443", the protocol is "https"
         if str(sb.port) == "443":
             sb.protocol = "https"
+    if (
+        (sb.enable_ws is None and sb.disable_ws is None)
+        or (sb.disable_ws is not None and not sb.disable_ws)
+        or (sb.enable_ws is not None and sb.enable_ws)
+    ):
+        sb.enable_ws = True
+        sb.disable_ws = False
+    else:
+        sb.enable_ws = False
+        sb.disable_ws = True
+    if sb.window_position:
+        window_position = sb.window_position
+        if window_position.count(",") != 1:
+            message = (
+                '\n\n  window_position expects an "x,y" string!'
+                '\n  (Your input was: "%s")\n' % window_position
+            )
+            raise Exception(message)
+        window_position = window_position.replace(" ", "")
+        win_x = None
+        win_y = None
+        try:
+            win_x = int(window_position.split(",")[0])
+            win_y = int(window_position.split(",")[1])
+        except Exception:
+            message = (
+                '\n\n  Expecting integer values for "x,y"!'
+                '\n  (window_position input was: "%s")\n'
+                % window_position
+            )
+            raise Exception(message)
+        settings.WINDOW_START_X = win_x
+        settings.WINDOW_START_Y = win_y
     if sb.window_size:
         window_size = sb.window_size
         if window_size.count(",") != 1:
@@ -758,11 +1014,20 @@ def get_configured_sb(context):
     # Set sb_config
     sb_config.browser = sb.browser
     sb_config.headless = sb.headless
+    sb_config.headless_active = False
     sb_config.headed = sb.headed
+    sb_config.is_behave = True
+    sb_config.is_pytest = False
+    sb_config.is_nosetest = False
+    sb_config.is_context_manager = False
+    sb_config.window_position = sb.window_position
     sb_config.window_size = sb.window_size
     sb_config.maximize_option = sb.maximize_option
     sb_config.xvfb = sb.xvfb
+    sb_config.xvfb_metrics = sb.xvfb_metrics
+    sb_config.reuse_class_session = sb._reuse_class_session
     sb_config.save_screenshot = sb.save_screenshot_after_test
+    sb_config.no_screenshot = sb.no_screenshot_after_test
     sb_config._has_logs = False
     sb_config.variables = sb.variables
     sb_config.dashboard = sb.dashboard
@@ -770,6 +1035,9 @@ def get_configured_sb(context):
     sb_config.pdb_option = sb.pdb_option
     sb_config.rec_behave = sb.rec_behave
     sb_config.rec_print = sb.rec_print
+    sb_config.disable_cookies = sb.disable_cookies
+    sb_config.disable_js = sb.disable_js
+    sb_config.disable_csp = sb.disable_csp
     sb_config.record_sleep = sb.record_sleep
     sb_config._is_timeout_changed = False
     sb_config._SMALL_TIMEOUT = settings.SMALL_TIMEOUT
@@ -799,10 +1067,11 @@ def get_configured_sb(context):
     if sb_config.dash_title:
         constants.Dashboard.TITLE = sb_config.dash_title.replace("_", " ")
 
-    log_helper.log_folder_setup(sb.log_path, sb.archive_logs)
+    log_helper.log_folder_setup(
+        constants.Logs.LATEST + "/", sb.archive_logs
+    )
     download_helper.reset_downloads_folder()
     proxy_helper.remove_proxy_zip_if_present()
-
     return sb
 
 
@@ -811,14 +1080,14 @@ def calculate_test_id(file_name, scenario_name):
     scenario_name = re.sub(r"[^\w" + r"_ " + r"]", "", scenario_name)
     scenario_name = scenario_name.replace(" ", "_")
     if " -- @" in scenario_name:
-        scenario_name = scenario_name.split(" -- @")[0]
+        scenario_name = scenario_name.split(" # ")[0].rstrip()
     test_id = "%s.%s" % (file_name, scenario_name)
     return test_id
 
 
 def calculate_display_id(file_name, line_num, scenario_name):
     if " -- @" in scenario_name:
-        scenario_name = scenario_name.split(" -- @")[0]
+        scenario_name = scenario_name.split(" # ")[0].rstrip()
     display_id = "%s:%s => %s" % (file_name, line_num, scenario_name)
     return display_id
 
@@ -828,7 +1097,7 @@ def get_test_id():
     file_name = file_name.replace("/", ".").replace("\\", ".")
     scenario_name = sb_config.behave_scenario.name
     if " -- @" in scenario_name:
-        scenario_name = scenario_name.split(" -- @")[0]
+        scenario_name = scenario_name.split(" # ")[0].rstrip()
     scenario_name = re.sub(r"[^\w" + r"_ " + r"]", "", scenario_name)
     scenario_name = scenario_name.replace(" ", "_")
     test_id = "%s.%s" % (file_name, scenario_name)
@@ -840,7 +1109,7 @@ def get_display_id():
     line_num = str(sb_config.behave_scenario.line)
     scenario_name = sb_config.behave_scenario.name
     if " -- @" in scenario_name:
-        scenario_name = scenario_name.split(" -- @")[0]
+        scenario_name = scenario_name.split(" # ")[0].rstrip()
     display_id = "%s:%s => %s" % (file_name, line_num, scenario_name)
     return display_id
 
@@ -915,7 +1184,7 @@ def dashboard_pre_processing():
             else:
                 scenario_name = row.split("  Scenario Outline: ")[-1]
             if " -- @" in scenario_name:
-                scenario_name = scenario_name.split(" -- @")[0]
+                scenario_name = scenario_name.split(" # ")[0].rstrip()
             elif " # features/" in scenario_name:
                 scenario_name = scenario_name.split(" # features/")[0]
             else:
@@ -938,7 +1207,7 @@ def dashboard_pre_processing():
 def _create_dashboard_assets_():
     import codecs
     from seleniumbase.js_code.live_js import live_js
-    from seleniumbase.core.style_sheet import pytest_style
+    from seleniumbase.core.style_sheet import get_pytest_style
 
     abs_path = os.path.abspath(".")
     assets_folder = os.path.join(abs_path, "assets")
@@ -950,11 +1219,11 @@ def _create_dashboard_assets_():
         existing_pytest_style = None
         with open(pytest_style_css, "r") as f:
             existing_pytest_style = f.read()
-        if existing_pytest_style == pytest_style:
+        if existing_pytest_style == get_pytest_style():
             add_pytest_style_css = False
     if add_pytest_style_css:
         out_file = codecs.open(pytest_style_css, "w+", encoding="utf-8")
-        out_file.writelines(pytest_style)
+        out_file.writelines(get_pytest_style())
         out_file.close()
     live_js_file = os.path.join(assets_folder, "live.js")
     add_live_js_file = True
@@ -976,29 +1245,24 @@ def behave_dashboard_prepare():
         _create_dashboard_assets_()
         # Output Dashboard info to the console
         sb_config.item_count_untested = sb_config.item_count
-        dash_path = os.getcwd() + "/dashboard.html"
+        dash_path = os.path.join(os.getcwd(), "dashboard.html")
         star_len = len("Dashboard: ") + len(dash_path)
-        try:
+        with suppress(Exception):
             terminal_size = os.get_terminal_size().columns
             if terminal_size > 30 and star_len > terminal_size:
                 star_len = terminal_size
-        except Exception:
-            pass
         stars = "*" * star_len
         c1 = ""
         cr = ""
-        if "linux" not in sys.platform:
-            colorama.init(autoreset=True)
+        if not is_linux:
             c1 = colorama.Fore.BLUE + colorama.Back.LIGHTCYAN_EX
             cr = colorama.Style.RESET_ALL
         print("Dashboard: %s%s%s\n%s" % (c1, dash_path, cr, stars))
 
 
 def _perform_behave_unconfigure_():
-    from seleniumbase.core import log_helper
-    from seleniumbase.core import proxy_helper
-
-    proxy_helper.remove_proxy_zip_if_present()
+    if hasattr(sb_config, "multi_proxy") and not sb_config.multi_proxy:
+        proxy_helper.remove_proxy_zip_if_present()
     if hasattr(sb_config, "reuse_session") and sb_config.reuse_session:
         # Close the shared browser session
         if sb_config.shared_driver:
@@ -1014,10 +1278,11 @@ def _perform_behave_unconfigure_():
             except Exception:
                 pass
         sb_config.shared_driver = None
-    if hasattr(sb_config, "log_path"):
+    if hasattr(sb_config, "archive_logs"):
         log_helper.archive_logs_if_set(
-            sb_config.log_path, sb_config.archive_logs
+            constants.Logs.LATEST + "/", sb_config.archive_logs
         )
+    log_helper.clear_empty_logs()
     # Dashboard post-processing: Disable time-based refresh and stamp complete
     if not hasattr(sb_config, "dashboard") or not sb_config.dashboard:
         # Done with "behave_unconfigure" unless using the Dashboard
@@ -1031,8 +1296,11 @@ def _perform_behave_unconfigure_():
     )
     find_it_3 = '<td class="col-result">Untested</td>'
     swap_with_3 = '<td class="col-result">Unreported</td>'
-    find_it_4 = 'href="%s"' % constants.Dashboard.DASH_PIE_PNG_1
-    swap_with_4 = 'href="%s"' % constants.Dashboard.DASH_PIE_PNG_2
+    # These use caching to prevent extra method calls
+    DASH_PIE_PNG_1 = constants.Dashboard.get_dash_pie_1()
+    DASH_PIE_PNG_2 = constants.Dashboard.get_dash_pie_2()
+    find_it_4 = 'href="%s"' % DASH_PIE_PNG_1
+    swap_with_4 = 'href="%s"' % DASH_PIE_PNG_2
     try:
         abs_path = os.path.abspath(".")
         dashboard_path = os.path.join(abs_path, "dashboard.html")
@@ -1068,7 +1336,7 @@ def _perform_behave_unconfigure_():
 
 
 def do_final_driver_cleanup_as_needed():
-    try:
+    with suppress(Exception):
         if hasattr(sb_config, "last_driver") and sb_config.last_driver:
             if (
                 not is_windows
@@ -1076,25 +1344,22 @@ def do_final_driver_cleanup_as_needed():
                 or sb_config.last_driver.service.process
             ):
                 sb_config.last_driver.quit()
-    except Exception:
-        pass
 
 
 def _perform_behave_terminal_summary_():
-    latest_logs_dir = os.getcwd() + "/latest_logs/"
-    dash_path = os.getcwd() + "/dashboard.html"
+    latest_logs_dir = os.path.join(
+        os.getcwd(), constants.Logs.LATEST + os.sep
+    )
+    dash_path = os.path.join(os.getcwd(), "dashboard.html")
     equals_len = len("Dashboard: ") + len(dash_path)
-    try:
+    with suppress(Exception):
         terminal_size = os.get_terminal_size().columns
         if terminal_size > 30 and equals_len > terminal_size:
             equals_len = terminal_size
-    except Exception:
-        pass
     equals = "=" * (equals_len + 2)
     c2 = ""
     cr = ""
-    if "linux" not in sys.platform:
-        colorama.init(autoreset=True)
+    if not is_linux:
         c2 = colorama.Fore.MAGENTA + colorama.Back.LIGHTYELLOW_EX
         cr = colorama.Style.RESET_ALL
     if sb_config.dashboard:
@@ -1136,6 +1401,7 @@ def before_all(context):
 
 def before_feature(context, feature):
     sb_config.behave_feature = feature
+    session_helper.end_reused_class_session_as_needed()
 
 
 def before_scenario(context, scenario):
@@ -1170,6 +1436,7 @@ def after_scenario(context, scenario):
 
 def after_feature(context, feature):
     sb_config.feature = feature
+    session_helper.end_reused_class_session_as_needed()
 
 
 def after_all(context):
