@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Creates a new SeleniumBase chart presentation with boilerplate code.
 
@@ -23,7 +22,6 @@ Output:
     and use a "sky" theme with "slide" transition.
     The chart can be used as a basic boilerplate.
 """
-
 import codecs
 import colorama
 import os
@@ -33,22 +31,22 @@ import sys
 def invalid_run_command(msg=None):
     exp = "  ** mkchart **\n\n"
     exp += "  Usage:\n"
-    exp += "          seleniumbase mkchart [FILE.py] [LANG]\n"
-    exp += "          OR     sbase mkchart [FILE.py] [LANG]\n"
+    exp += "     seleniumbase mkchart [FILE.py] [LANG]\n"
+    exp += "     OR     sbase mkchart [FILE.py] [LANG]\n"
     exp += "  Example:\n"
-    exp += "          sbase mkchart new_chart.py --en\n"
+    exp += "     sbase mkchart new_chart.py --en\n"
     exp += "  Language Options:\n"
-    exp += "          --en / --English    |    --zh / --Chinese\n"
-    exp += "          --nl / --Dutch      |    --fr / --French\n"
-    exp += "          --it / --Italian    |    --ja / --Japanese\n"
-    exp += "          --ko / --Korean     |    --pt / --Portuguese\n"
-    exp += "          --ru / --Russian    |    --es / --Spanish\n"
+    exp += "     --en / --English    |    --zh / --Chinese\n"
+    exp += "     --nl / --Dutch      |    --fr / --French\n"
+    exp += "     --it / --Italian    |    --ja / --Japanese\n"
+    exp += "     --ko / --Korean     |    --pt / --Portuguese\n"
+    exp += "     --ru / --Russian    |    --es / --Spanish\n"
     exp += "  Output:\n"
-    exp += "          Creates a new SeleniumBase chart presentation.\n"
-    exp += "          If the file already exists, an error is raised.\n"
-    exp += "          By default, the slides are written in English,\n"
-    exp += '          and use a "sky" theme with "slide" transition.\n'
-    exp += "          The chart can be used as a basic boilerplate.\n"
+    exp += "     Creates a new SeleniumBase chart presentation.\n"
+    exp += "     If the file already exists, an error is raised.\n"
+    exp += "     By default, the slides are written in English,\n"
+    exp += '     and use a "sky" theme with "slide" transition.\n'
+    exp += "     The chart can be used as a basic boilerplate.\n"
     if not msg:
         raise Exception("INVALID RUN COMMAND!\n\n%s" % exp)
     elif msg == "help":
@@ -64,7 +62,6 @@ def main():
     c7 = ""
     cr = ""
     if "linux" not in sys.platform:
-        colorama.init(autoreset=True)
         c1 = colorama.Fore.BLUE + colorama.Back.LIGHTCYAN_EX
         c5 = colorama.Fore.RED + colorama.Back.LIGHTYELLOW_EX
         c7 = colorama.Fore.BLACK + colorama.Back.MAGENTA
@@ -130,14 +127,6 @@ def main():
     if help_me:
         invalid_run_command(invalid_cmd)
 
-    if language != "English" and sys.version_info[0] == 2:
-        print("")
-        msg = 'Multi-language support for "sbase mkchart" '
-        msg += "is not available on Python 2!"
-        msg = "\n" + c5 + msg + cr
-        msg += '\nPlease run in "English" mode or upgrade to Python 3!\n'
-        raise Exception(msg)
-
     dir_name = os.getcwd()
     file_path = "%s/%s" % (dir_name, file_name)
     html_name = file_name.replace(".py", ".html")
@@ -193,8 +182,8 @@ def main():
         chart_options = '"circular", "barras", "columnas", "líneas", "área"'
 
     import_line = "from seleniumbase import BaseCase"
+    main_line = "BaseCase.main(__name__, __file__)"
     parent_class = "BaseCase"
-    class_line = "class MyTestClass(BaseCase):"
     if language != "English":
         from seleniumbase.translate.master_dict import MD_F
 
@@ -206,6 +195,7 @@ def main():
     add_slide = '"<p>Chart Demo</p>" + self.extract_chart()'
     data = []
     data.append("%s" % import_line)
+    data.append("%s" % main_line)
     data.append("")
     data.append("")
     data.append("%s" % class_line)
@@ -214,12 +204,12 @@ def main():
     data.append("")
     data.append("        # %s => %s" % (select_option, chart_options))
     data.append("        self.create_pie_chart(%s)" % chart_settings)
-    data.append('        self.add_data_point("%s A", 50)' % item)
-    data.append('        self.add_data_point("%s B", 40)' % item)
-    data.append('        self.add_data_point("%s C", 35)' % item)
-    data.append('        self.add_data_point("%s D", 30)' % item)
-    data.append('        self.add_data_point("%s E", 25)' % item)
-    data.append('        self.add_data_point("%s F", 20)' % item)
+    data.append('        self.add_data_point("%s A", 36)' % item)
+    data.append('        self.add_data_point("%s B", 33)' % item)
+    data.append('        self.add_data_point("%s C", 27)' % item)
+    data.append('        self.add_data_point("%s D", 21)' % item)
+    data.append('        self.add_data_point("%s E", 18)' % item)
+    data.append('        self.add_data_point("%s F", 15)' % item)
     data.append("        self.add_slide(%s)" % add_slide)
     data.append("")
     data.append('        self.begin_presentation(filename="%s")' % html_name)
@@ -253,6 +243,10 @@ def main():
                         # Example: self.assert_true("Name" in self.get_title())
                         line = new_line
                         continue
+            if main_line in line:
+                new_main = "%s.main(__name__, __file__)" % parent_class
+                new_line = line.replace(main_line, new_main)
+                found_swap = True
             if found_swap:
                 if new_line.endswith("  # noqa"):  # Remove flake8 skip
                     new_line = new_line[0 : -len("  # noqa")]
