@@ -636,17 +636,12 @@ def main():
     data.append("")
     data.append("class GoogleTests(BaseCase):")
     data.append("    def test_google_dot_com(self):")
+    data.append("        if self.headless:")
+    data.append('            self.skip("Skipping test in headless mode.")')
     data.append("        if not self.undetectable:")
     data.append("            self.get_new_driver(undetectable=True)")
     data.append('        self.open("https://google.com/ncr")')
     data.append('        self.assert_title_contains("Google")')
-    data.append("        self.sleep(0.05)")
-    data.append("        self.save_screenshot_to_logs()")
-    data.append(
-        "        self.wait_for_element('iframe[role=\"presentation\"]')"
-    )
-    data.append("        self.hide_elements('iframe')")
-    data.append("        self.sleep(0.05)")
     data.append("        self.save_screenshot_to_logs()")
     data.append('        self.type(HomePage.search_box, "github.com")')
     data.append("        self.assert_element(HomePage.search_button)")
