@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Creates a new SeleniumBase presentation with boilerplate code.
 
@@ -23,7 +22,6 @@ Output:
     and use "serif" theme with "slide" transition.
     The slides can be used as a basic boilerplate.
 """
-
 import codecs
 import colorama
 import os
@@ -33,22 +31,22 @@ import sys
 def invalid_run_command(msg=None):
     exp = "  ** mkpres **\n\n"
     exp += "  Usage:\n"
-    exp += "          seleniumbase mkpres [FILE.py] [LANG]\n"
-    exp += "          OR     sbase mkpres [FILE.py] [LANG]\n"
+    exp += "     seleniumbase mkpres [FILE.py] [LANG]\n"
+    exp += "     OR     sbase mkpres [FILE.py] [LANG]\n"
     exp += "  Example:\n"
-    exp += "          sbase mkpres new_presentation.py --en\n"
+    exp += "     sbase mkpres new_presentation.py --en\n"
     exp += "  Language Options:\n"
-    exp += "          --en / --English    |    --zh / --Chinese\n"
-    exp += "          --nl / --Dutch      |    --fr / --French\n"
-    exp += "          --it / --Italian    |    --ja / --Japanese\n"
-    exp += "          --ko / --Korean     |    --pt / --Portuguese\n"
-    exp += "          --ru / --Russian    |    --es / --Spanish\n"
+    exp += "     --en / --English    |    --zh / --Chinese\n"
+    exp += "     --nl / --Dutch      |    --fr / --French\n"
+    exp += "     --it / --Italian    |    --ja / --Japanese\n"
+    exp += "     --ko / --Korean     |    --pt / --Portuguese\n"
+    exp += "     --ru / --Russian    |    --es / --Spanish\n"
     exp += "  Output:\n"
-    exp += "          Creates a new presentation with 3 example slides.\n"
-    exp += "          If the file already exists, an error is raised.\n"
-    exp += "          By default, the slides are written in English,\n"
-    exp += '          and use "serif" theme with "slide" transition.\n'
-    exp += "          The slides can be used as a basic boilerplate.\n"
+    exp += "     Creates a new presentation with 3 example slides.\n"
+    exp += "     If the file already exists, an error is raised.\n"
+    exp += "     By default, the slides are written in English,\n"
+    exp += '     and use "serif" theme with "slide" transition.\n'
+    exp += "     The slides can be used as a basic boilerplate.\n"
     if not msg:
         raise Exception("INVALID RUN COMMAND!\n\n%s" % exp)
     elif msg == "help":
@@ -64,7 +62,6 @@ def main():
     c7 = ""
     cr = ""
     if "linux" not in sys.platform:
-        colorama.init(autoreset=True)
         c1 = colorama.Fore.BLUE + colorama.Back.LIGHTCYAN_EX
         c5 = colorama.Fore.RED + colorama.Back.LIGHTYELLOW_EX
         c7 = colorama.Fore.BLACK + colorama.Back.MAGENTA
@@ -130,14 +127,6 @@ def main():
     if help_me:
         invalid_run_command(invalid_cmd)
 
-    if language != "English" and sys.version_info[0] == 2:
-        print("")
-        msg = 'Multi-language support for "sbase mkpres" '
-        msg += "is not available on Python 2!"
-        msg = "\n" + c5 + msg + cr
-        msg += '\nPlease run in "English" mode or upgrade to Python 3!\n'
-        raise Exception(msg)
-
     dir_name = os.getcwd()
     file_path = "%s/%s" % (dir_name, file_name)
     html_name = file_name.replace(".py", ".html")
@@ -204,8 +193,8 @@ def main():
         class_name = "MiClaseDePrueba"
 
     import_line = "from seleniumbase import BaseCase"
+    main_line = "BaseCase.main(__name__, __file__)"
     parent_class = "BaseCase"
-    class_line = "class MyTestClass(BaseCase):"
     if language != "English":
         from seleniumbase.translate.master_dict import MD_F
 
@@ -213,8 +202,8 @@ def main():
         parent_class = MD_F.get_lang_parent_class(language)
     class_line = "class %s(%s):" % (class_name, parent_class)
     settings = 'theme="serif", transition="slide"'
-    img_src_1 = 'src="https://seleniumbase.io/cdn/gif/chart_pres.gif"'
-    img_src_2 = 'src="https://seleniumbase.io/cdn/img/sb_logo_10.png"'
+    img_src_1 = 'src="https://seleniumbase.github.io/cdn/gif/chart_pres.gif"'
+    img_src_2 = 'src="https://seleniumbase.github.io/cdn/img/sb_logo_10.png"'
     hello_page = (
         "\n            '<h1>%s</h1><hr /><br />'"
         "\n            '<p>%s</p>'"
@@ -233,6 +222,7 @@ def main():
 
     data = []
     data.append("%s" % import_line)
+    data.append("%s" % main_line)
     data.append("")
     data.append("")
     data.append("%s" % class_line)
@@ -272,6 +262,10 @@ def main():
                         # Example: self.assert_true("Name" in self.get_title())
                         line = new_line
                         continue
+            if main_line in line:
+                new_main = "%s.main(__name__, __file__)" % parent_class
+                new_line = line.replace(main_line, new_main)
+                found_swap = True
             if found_swap:
                 if new_line.endswith("  # noqa"):  # Remove flake8 skip
                     new_line = new_line[0 : -len("  # noqa")]
