@@ -1,14 +1,8 @@
-"""
-Method for generating application strings used in the Testcase Database.
-"""
-
 import time
 
 
 class ApplicationManager:
-    """
-    This class contains methods to generate application strings.
-    """
+    """Generating application strings for the Testcase Database."""
 
     @classmethod
     def generate_application_string(cls, test):
