@@ -1,12 +1,9 @@
-"""
-This module contains methods for running website tours.
-These helper methods SHOULD NOT be called directly from tests.
-"""
+"""This module contains methods for running website tours.
+These helper methods SHOULD NOT be called directly from tests."""
 import os
 import re
 import textwrap
 import time
-from selenium.webdriver.common.by import By
 from seleniumbase import config as sb_config
 from seleniumbase.config import settings
 from seleniumbase.core import style_sheet
@@ -28,7 +25,7 @@ def activate_bootstrap(driver):
                      var tour2 = new Tour({
                      });"""
 
-    backdrop_style = style_sheet.bt_backdrop_style
+    backdrop_style = style_sheet.get_bt_backdrop_style()
     js_utils.add_css_style(driver, backdrop_style)
     js_utils.wait_for_ready_state_complete(driver)
     js_utils.wait_for_angularjs(driver)
@@ -63,7 +60,7 @@ def activate_driverjs(driver):
     """Allows you to use DriverJS Tours with SeleniumBase
     https://kamranahmed.info/driver.js/
     """
-    backdrop_style = style_sheet.dt_backdrop_style
+    backdrop_style = style_sheet.get_dt_backdrop_style()
     driverjs_css = constants.DriverJS.MIN_CSS
     driverjs_js = constants.DriverJS.MIN_JS
 
@@ -71,7 +68,6 @@ def activate_driverjs(driver):
                      var driverjs2 = Driver.name;
                      """
 
-    activate_bootstrap(driver)
     js_utils.wait_for_ready_state_complete(driver)
     js_utils.wait_for_angularjs(driver)
     js_utils.add_css_style(driver, backdrop_style)
@@ -110,13 +106,12 @@ def activate_hopscotch(driver):
     """
     hopscotch_css = constants.Hopscotch.MIN_CSS
     hopscotch_js = constants.Hopscotch.MIN_JS
-    backdrop_style = style_sheet.hops_backdrop_style
+    backdrop_style = style_sheet.get_hops_backdrop_style()
 
     verify_script = """// Verify Hopscotch activated
                      var hops = hopscotch.isActive;
                      """
 
-    activate_bootstrap(driver)
     js_utils.wait_for_ready_state_complete(driver)
     js_utils.wait_for_angularjs(driver)
     js_utils.add_css_style(driver, backdrop_style)
@@ -158,7 +153,7 @@ def activate_introjs(driver):
 
     theme_color = sb_config.introjs_theme_color
     hover_color = sb_config.introjs_hover_color
-    backdrop_style = style_sheet.introjs_style % (
+    backdrop_style = style_sheet.get_introjs_style() % (
         theme_color,
         hover_color,
         hover_color,
@@ -170,7 +165,6 @@ def activate_introjs(driver):
                      var intro2 = introJs();
                      """
 
-    activate_bootstrap(driver)
     js_utils.wait_for_ready_state_complete(driver)
     js_utils.wait_for_angularjs(driver)
     js_utils.add_css_style(driver, backdrop_style)
@@ -216,10 +210,9 @@ def activate_shepherd(driver):
     sh_theme_sq_dark_css = constants.Shepherd.THEME_SQ_DK_CSS
     tether_js = constants.Tether.MIN_JS
     spinner_css = constants.Messenger.SPINNER_CSS
-    sh_style = style_sheet.sh_style_test
-    backdrop_style = style_sheet.sh_backdrop_style
+    sh_style = style_sheet.get_sh_style_test()
+    backdrop_style = style_sheet.get_sh_backdrop_style()
 
-    activate_bootstrap(driver)
     js_utils.wait_for_ready_state_complete(driver)
     js_utils.wait_for_angularjs(driver)
     js_utils.add_css_style(driver, backdrop_style)
@@ -253,7 +246,7 @@ def activate_shepherd(driver):
 
 
 def is_shepherd_activated(driver):
-    sh_style = style_sheet.sh_style_test
+    sh_style = style_sheet.get_sh_style_test()
     try:
         driver.execute_script(sh_style)  # Verify Shepherd has loaded
         return True
@@ -270,6 +263,13 @@ def play_shepherd_tour(driver, tour_steps, msg_dur, name=None, interval=0):
         // Start the tour
         tour.start();
         $tour = tour;"""
+    extra = """
+        document.body.addEventListener('keyup', function (event) {
+        if (event.key === 'PageUp' || event.key === 'ArrowLeft') {
+            Shepherd.activeTour.back(); }
+        if (event.key === 'PageDown' || event.key === 'ArrowRight') {
+            Shepherd.activeTour.next(); }
+        })"""
     autoplay = False
     if interval and interval > 0:
         autoplay = True
@@ -278,6 +278,7 @@ def play_shepherd_tour(driver, tour_steps, msg_dur, name=None, interval=0):
             interval = 0.5
 
     if not is_shepherd_activated(driver):
+        instructions += extra
         activate_shepherd(driver)
 
     if len(tour_steps[name]) > 1:
@@ -290,7 +291,7 @@ def play_shepherd_tour(driver, tour_steps, msg_dur, name=None, interval=0):
             page_actions.wait_for_element_present(
                 driver,
                 selector,
-                by=By.CSS_SELECTOR,
+                by="css selector",
                 timeout=settings.SMALL_TIMEOUT,
             )
         except Exception:
@@ -303,6 +304,16 @@ def play_shepherd_tour(driver, tour_steps, msg_dur, name=None, interval=0):
                 "" % selector
             )
     driver.execute_script(instructions)
+    try:
+        page_actions.wait_for_element_visible(
+            driver, "a.tour-button-right", by="css selector", timeout=1.2
+        )
+    except Exception:
+        pass
+    try:
+        driver.execute_script('document.activeElement.blur();')
+    except Exception:
+        pass
     tour_on = True
     if autoplay:
         start_ms = time.time() * 1000.0
@@ -405,7 +416,6 @@ def play_bootstrap_tour(
         tour.restart();
         // Save for later
         $tour = tour;"""
-
     if interval and interval > 0:
         if interval < 1:
             interval = 1
@@ -413,10 +423,8 @@ def play_bootstrap_tour(
         instructions = instructions.replace(
             "duration: 0,", "duration: %s," % interval
         )
-
     if not is_bootstrap_activated(driver):
         activate_bootstrap(driver)
-
     if len(tour_steps[name]) > 1:
         try:
             if "element: " in tour_steps[name][1]:
@@ -428,7 +436,7 @@ def play_bootstrap_tour(
                 page_actions.wait_for_element_present(
                     driver,
                     selector,
-                    by=By.CSS_SELECTOR,
+                    by="css selector",
                     timeout=settings.SMALL_TIMEOUT,
                 )
             else:
@@ -442,9 +450,18 @@ def play_bootstrap_tour(
                 "Exiting due to failure on first tour step!"
                 "" % selector
             )
-
     driver.execute_script(instructions)
     tour_on = True
+    try:
+        page_actions.wait_for_element_visible(
+            driver, ".tour-tour", by="css selector", timeout=1.2
+        )
+    except Exception:
+        pass
+    try:
+        driver.execute_script('document.activeElement.blur();')
+    except Exception:
+        pass
     while tour_on:
         try:
             time.sleep(0.01)
@@ -452,7 +469,7 @@ def play_bootstrap_tour(
                 result = driver.execute_script("return $tour.ended()")
             else:
                 page_actions.wait_for_element_present(
-                    driver, ".tour-tour", by=By.CSS_SELECTOR, timeout=0.65
+                    driver, ".tour-tour", by="css selector", timeout=0.48
                 )
                 result = False
         except Exception:
@@ -468,7 +485,7 @@ def play_bootstrap_tour(
                     result = driver.execute_script("return $tour.ended()")
                 else:
                     page_actions.wait_for_element_present(
-                        driver, ".tour-tour", by=By.CSS_SELECTOR, timeout=0.65
+                        driver, ".tour-tour", by="css selector", timeout=0.48
                     )
                     result = False
                 if result is False:
@@ -493,6 +510,11 @@ def play_driverjs_tour(
         // Start the tour!
         tour.start();
         $tour = tour;"""
+    extra = """
+        document.body.addEventListener('keyup', function (event) {
+        if (event.key === 'PageUp') { $tour.movePrevious(); }
+        if (event.key === 'PageDown') { $tour.moveNext(); }
+        })"""
     autoplay = False
     if interval and interval > 0:
         autoplay = True
@@ -501,6 +523,7 @@ def play_driverjs_tour(
             interval = 0.5
 
     if not is_driverjs_activated(driver):
+        instructions += extra
         activate_driverjs(driver)
 
     if len(tour_steps[name]) > 1:
@@ -514,7 +537,7 @@ def play_driverjs_tour(
                 page_actions.wait_for_element_present(
                     driver,
                     selector,
-                    by=By.CSS_SELECTOR,
+                    by="css selector",
                     timeout=settings.SMALL_TIMEOUT,
                 )
             else:
@@ -547,7 +570,7 @@ def play_driverjs_tour(
                 page_actions.wait_for_element_visible(
                     driver,
                     "#driver-popover-item",
-                    by=By.CSS_SELECTOR,
+                    by="css selector",
                     timeout=1.1,
                 )
                 result = False
@@ -594,7 +617,7 @@ def play_driverjs_tour(
                     page_actions.wait_for_element_visible(
                         driver,
                         "#driver-popover-item",
-                        by=By.CSS_SELECTOR,
+                        by="css selector",
                         timeout=1.1,
                     )
                     result = False
@@ -620,6 +643,13 @@ def play_hopscotch_tour(
         // Start the tour!
         hopscotch.startTour(tour);
         $tour = hopscotch;"""
+    extra = """
+        document.body.addEventListener('keyup', function (event) {
+        if (event.key === 'PageUp' || event.key === 'ArrowLeft') {
+            $tour.prevStep(); }
+        if (event.key === 'PageDown' || event.key === 'ArrowRight') {
+            $tour.nextStep(); }
+        })"""
     autoplay = False
     if interval and interval > 0:
         autoplay = True
@@ -628,6 +658,7 @@ def play_hopscotch_tour(
             interval = 0.5
 
     if not is_hopscotch_activated(driver):
+        instructions += extra
         activate_hopscotch(driver)
 
     if len(tour_steps[name]) > 1:
@@ -641,7 +672,7 @@ def play_hopscotch_tour(
                 page_actions.wait_for_element_present(
                     driver,
                     selector,
-                    by=By.CSS_SELECTOR,
+                    by="css selector",
                     timeout=settings.SMALL_TIMEOUT,
                 )
             else:
@@ -657,6 +688,16 @@ def play_hopscotch_tour(
             )
 
     driver.execute_script(instructions)
+    try:
+        page_actions.wait_for_element_visible(
+            driver, "button.hopscotch-next", by="css selector", timeout=1.2
+        )
+    except Exception:
+        pass
+    try:
+        driver.execute_script('document.activeElement.blur();')
+    except Exception:
+        pass
     tour_on = True
     if autoplay:
         start_ms = time.time() * 1000.0
@@ -671,7 +712,7 @@ def play_hopscotch_tour(
                 page_actions.wait_for_element_present(
                     driver,
                     ".hopscotch-bubble",
-                    by=By.CSS_SELECTOR,
+                    by="css selector",
                     timeout=0.4,
                 )
                 result = False
@@ -713,7 +754,7 @@ def play_hopscotch_tour(
                     page_actions.wait_for_element_present(
                         driver,
                         ".hopscotch-bubble",
-                        by=By.CSS_SELECTOR,
+                        by="css selector",
                         timeout=0.4,
                     )
                     result = False
@@ -752,6 +793,11 @@ def play_introjs_tour(
         // Start the tour
         startIntro();
         """
+    extra = """
+        document.body.addEventListener('keyup', function (event) {
+        if (event.key === 'PageUp') { $tour.previousStep(); }
+        if (event.key === 'PageDown') { $tour.nextStep(); }
+        })"""
     autoplay = False
     if interval and interval > 0:
         autoplay = True
@@ -760,6 +806,7 @@ def play_introjs_tour(
             interval = 0.5
 
     if not is_introjs_activated(driver):
+        instructions += extra
         activate_introjs(driver)
 
     if len(tour_steps[name]) > 1:
@@ -773,7 +820,7 @@ def play_introjs_tour(
                 page_actions.wait_for_element_present(
                     driver,
                     selector,
-                    by=By.CSS_SELECTOR,
+                    by="css selector",
                     timeout=settings.SMALL_TIMEOUT,
                 )
             else:
@@ -800,7 +847,7 @@ def play_introjs_tour(
                 result = driver.execute_script("return $tour._currentStep")
             else:
                 page_actions.wait_for_element_present(
-                    driver, ".introjs-tooltip", by=By.CSS_SELECTOR, timeout=0.4
+                    driver, ".introjs-tooltip", by="css selector", timeout=0.4
                 )
                 result = True
         except Exception:
@@ -844,7 +891,7 @@ def play_introjs_tour(
                     page_actions.wait_for_element_present(
                         driver,
                         ".introjs-tooltip",
-                        by=By.CSS_SELECTOR,
+                        by="css selector",
                         timeout=0.4,
                     )
                     result = True
@@ -924,7 +971,7 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
         jquery_js = constants.JQuery.MIN_JS
         bootstrap_tour_css = constants.BootstrapTour.MIN_CSS
         bootstrap_tour_js = constants.BootstrapTour.MIN_JS
-        backdrop_style = style_sheet.bt_backdrop_style
+        backdrop_style = style_sheet.get_bt_backdrop_style()
         backdrop_style = backdrop_style.replace("\n", "")
         backdrop_style = js_utils.escape_quotes_if_needed(backdrop_style)
         instructions += 'injectJS("%s");\n' % jquery_js
@@ -941,7 +988,7 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
     elif tour_type == "driverjs":
         driverjs_css = constants.DriverJS.MIN_CSS
         driverjs_js = constants.DriverJS.MIN_JS
-        backdrop_style = style_sheet.dt_backdrop_style
+        backdrop_style = style_sheet.get_dt_backdrop_style()
         backdrop_style = backdrop_style.replace("\n", "")
         backdrop_style = js_utils.escape_quotes_if_needed(backdrop_style)
         instructions += 'injectCSS("%s");\n' % driverjs_css
@@ -951,7 +998,7 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
     elif tour_type == "hopscotch":
         hopscotch_css = constants.Hopscotch.MIN_CSS
         hopscotch_js = constants.Hopscotch.MIN_JS
-        backdrop_style = style_sheet.hops_backdrop_style
+        backdrop_style = style_sheet.get_hops_backdrop_style()
         backdrop_style = backdrop_style.replace("\n", "")
         backdrop_style = js_utils.escape_quotes_if_needed(backdrop_style)
         instructions += 'injectCSS("%s");\n' % hopscotch_css
@@ -963,7 +1010,7 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
         intro_js = constants.IntroJS.MIN_JS
         theme_color = sb_config.introjs_theme_color
         hover_color = sb_config.introjs_hover_color
-        backdrop_style = style_sheet.introjs_style % (
+        backdrop_style = style_sheet.get_introjs_style() % (
             theme_color,
             hover_color,
             hover_color,
@@ -987,7 +1034,7 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
         sh_theme_sq_dark_css = constants.Shepherd.THEME_SQ_DK_CSS
         tether_js = constants.Tether.MIN_JS
         spinner_css = constants.Messenger.SPINNER_CSS
-        backdrop_style = style_sheet.sh_backdrop_style
+        backdrop_style = style_sheet.get_sh_backdrop_style()
         backdrop_style = backdrop_style.replace("\n", "")
         backdrop_style = js_utils.escape_quotes_if_needed(backdrop_style)
         instructions += 'injectCSS("%s");\n' % spinner_css
