@@ -1,10 +1,8 @@
-"""
-Convert XPath selectors into CSS selectors
-"""
+"""Convert XPath selectors into CSS selectors"""
 import re
 
 _sub_regexes = {
-    "tag": r"([a-zA-Z][a-zA-Z0-9]{0,10}|\*)",
+    "tag": r"([a-zA-Z][-a-zA-Z0-9]{0,40}|\*)",
     "attribute": r"[.a-zA-Z_:][-\w:.]*(\(\))?)",
     "value": r"\s*[\w/:][-/\w\s,:;.\S]*",
 }
