@@ -1,11 +1,11 @@
-# French / Français - Translations - Python 3 Only!
+# French / Français - Translations
 from seleniumbase import BaseCase
 from seleniumbase import MasterQA
 
 
 class CasDeBase(BaseCase):
     def __init__(self, *args, **kwargs):
-        super(CasDeBase, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._language = "French"
 
     def ouvrir(self, *args, **kwargs):
@@ -24,18 +24,31 @@ class CasDeBase(BaseCase):
         # double_click(selector)
         return self.double_click(*args, **kwargs)
 
+    def contextuel_cliquer(self, *args, **kwargs):
+        # context_click(selector)
+        return self.context_click(*args, **kwargs)
+
     def cliquer_lentement(self, *args, **kwargs):
         # slow_click(selector)
         return self.slow_click(*args, **kwargs)
 
-    def cliquer_si_affiché(self, *args, **kwargs):  # noqa
+    def cliquer_si_affiché(self, *args, **kwargs):
         # click_if_visible(selector, by=By.CSS_SELECTOR)
         return self.click_if_visible(*args, **kwargs)
 
+    def js_cliquer_si_présent(self, *args, **kwargs):
+        # js_click_if_present(selector, by=By.CSS_SELECTOR)
+        return self.js_click_if_present(*args, **kwargs)
+
     def cliquer_texte_du_lien(self, *args, **kwargs):
         # click_link_text(link_text)
         return self.click_link_text(*args, **kwargs)
 
+    def cliquer_emplacement(self, *args, **kwargs):
+        # click_with_offset(selector, x, y, by=By.CSS_SELECTOR,
+        #                   mark=None, timeout=None, center=None)
+        return self.click_with_offset(*args, **kwargs)
+
     def modifier_texte(self, *args, **kwargs):
         # update_text(selector, text)
         return self.update_text(*args, **kwargs)
@@ -64,6 +77,14 @@ class CasDeBase(BaseCase):
         # assert_link_text(link_text)
         return self.assert_link_text(*args, **kwargs)
 
+    def vérifier_texte_non_vide(self, *args, **kwargs):
+        # assert_non_empty_text(selector)
+        return self.assert_non_empty_text(*args, **kwargs)
+
+    def vérifier_texte_pas_affiché(self, *args, **kwargs):
+        # assert_text_not_visible(text, selector)
+        return self.assert_text_not_visible(*args, **kwargs)
+
     def vérifier_élément(self, *args, **kwargs):
         # assert_element(selector)
         return self.assert_element(*args, **kwargs)
@@ -88,10 +109,22 @@ class CasDeBase(BaseCase):
         # assert_attribute(selector, attribute, value)
         return self.assert_attribute(*args, **kwargs)
 
+    def vérifier_url(self, *args, **kwargs):
+        # assert_url(url)
+        return self.assert_url(*args, **kwargs)
+
+    def vérifier_url_contient(self, *args, **kwargs):
+        # assert_url_contains(substring)
+        return self.assert_url_contains(*args, **kwargs)
+
     def vérifier_titre(self, *args, **kwargs):
         # assert_title(title)
         return self.assert_title(*args, **kwargs)
 
+    def vérifier_titre_contient(self, *args, **kwargs):
+        # assert_title_contains(substring)
+        return self.assert_title_contains(*args, **kwargs)
+
     def obtenir_titre(self, *args, **kwargs):
         # get_title()
         return self.get_title(*args, **kwargs)
@@ -136,6 +169,10 @@ class CasDeBase(BaseCase):
         # is_text_visible(text, selector="html")
         return self.is_text_visible(*args, **kwargs)
 
+    def est_texte_exactement_affiché(self, *args, **kwargs):
+        # is_exact_text_visible(text, selector="html")
+        return self.is_exact_text_visible(*args, **kwargs)
+
     def est_un_élément_affiché(self, *args, **kwargs):
         # is_element_visible(selector)
         return self.is_element_visible(*args, **kwargs)
@@ -176,6 +213,10 @@ class CasDeBase(BaseCase):
         # wait_for_attribute(selector, attribute, value)
         return self.wait_for_attribute(*args, **kwargs)
 
+    def attendre_que_la_page_se_charge(self, *args, **kwargs):
+        # wait_for_ready_state_complete()
+        return self.wait_for_ready_state_complete(*args, **kwargs)
+
     def dormir(self, *args, **kwargs):
         # sleep(seconds)
         return self.sleep(*args, **kwargs)
@@ -208,6 +249,18 @@ class CasDeBase(BaseCase):
         # js_type(selector, text)
         return self.js_type(*args, **kwargs)
 
+    def jquery_cliquer(self, *args, **kwargs):
+        # jquery_click(selector)
+        return self.jquery_click(*args, **kwargs)
+
+    def jquery_modifier_texte(self, *args, **kwargs):
+        # jquery_update_text(selector, text)
+        return self.jquery_update_text(*args, **kwargs)
+
+    def jquery_taper(self, *args, **kwargs):
+        # jquery_type(selector, text)
+        return self.jquery_type(*args, **kwargs)
+
     def vérifier_html(self, *args, **kwargs):
         # inspect_html()
         return self.inspect_html(*args, **kwargs)
@@ -312,10 +365,14 @@ class CasDeBase(BaseCase):
         # scroll_to_bottom()
         return self.scroll_to_bottom(*args, **kwargs)
 
-    def planer_au_dessus_et_cliquer(self, *args, **kwargs):
+    def passer_la_souris_et_cliquer(self, *args, **kwargs):
         # hover_and_click(hover_selector, click_selector)
         return self.hover_and_click(*args, **kwargs)
 
+    def survol_de_la_souris(self, *args, **kwargs):
+        # hover(selector)
+        return self.hover(*args, **kwargs)
+
     def est_il_sélectionné(self, *args, **kwargs):
         # is_selected(selector)
         return self.is_selected(*args, **kwargs)
