@@ -1,11 +1,11 @@
-# Italian / Italiano - Translations - Python 3 Only!
+# Italian / Italiano - Translations
 from seleniumbase import BaseCase
 from seleniumbase import MasterQA
 
 
 class CasoDiProva(BaseCase):
     def __init__(self, *args, **kwargs):
-        super(CasoDiProva, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._language = "Italian"
 
     def apri(self, *args, **kwargs):
@@ -24,6 +24,10 @@ class CasoDiProva(BaseCase):
         # double_click(selector)
         return self.double_click(*args, **kwargs)
 
+    def clic_contestuale(self, *args, **kwargs):
+        # context_click(selector)
+        return self.context_click(*args, **kwargs)
+
     def clic_lentamente(self, *args, **kwargs):
         # slow_click(selector)
         return self.slow_click(*args, **kwargs)
@@ -32,10 +36,19 @@ class CasoDiProva(BaseCase):
         # click_if_visible(selector, by=By.CSS_SELECTOR)
         return self.click_if_visible(*args, **kwargs)
 
+    def js_clic_se_presente(self, *args, **kwargs):
+        # js_click_if_present(selector, by=By.CSS_SELECTOR)
+        return self.js_click_if_present(*args, **kwargs)
+
     def clic_testo_del_collegamento(self, *args, **kwargs):
         # click_link_text(link_text)
         return self.click_link_text(*args, **kwargs)
 
+    def clic_su_posizione(self, *args, **kwargs):
+        # click_with_offset(selector, x, y, by=By.CSS_SELECTOR,
+        #                   mark=None, timeout=None, center=None)
+        return self.click_with_offset(*args, **kwargs)
+
     def aggiornare_testo(self, *args, **kwargs):
         # update_text(selector, text)
         return self.update_text(*args, **kwargs)
@@ -64,6 +77,14 @@ class CasoDiProva(BaseCase):
         # assert_link_text(link_text)
         return self.assert_link_text(*args, **kwargs)
 
+    def verificare_testo_non_vuoto(self, *args, **kwargs):
+        # assert_non_empty_text(selector)
+        return self.assert_non_empty_text(*args, **kwargs)
+
+    def verificare_testo_non_visto(self, *args, **kwargs):
+        # assert_text_not_visible(text, selector)
+        return self.assert_text_not_visible(*args, **kwargs)
+
     def verificare_elemento(self, *args, **kwargs):
         # assert_element(selector)
         return self.assert_element(*args, **kwargs)
@@ -88,10 +109,22 @@ class CasoDiProva(BaseCase):
         # assert_attribute(selector, attribute, value)
         return self.assert_attribute(*args, **kwargs)
 
+    def verificare_url(self, *args, **kwargs):
+        # assert_url(url)
+        return self.assert_url(*args, **kwargs)
+
+    def verificare_url_contiene(self, *args, **kwargs):
+        # assert_url_contains(substring)
+        return self.assert_url_contains(*args, **kwargs)
+
     def verificare_titolo(self, *args, **kwargs):
         # assert_title(title)
         return self.assert_title(*args, **kwargs)
 
+    def verificare_titolo_contiene(self, *args, **kwargs):
+        # assert_title_contains(substring)
+        return self.assert_title_contains(*args, **kwargs)
+
     def ottenere_titolo(self, *args, **kwargs):
         # get_title()
         return self.get_title(*args, **kwargs)
@@ -132,10 +165,14 @@ class CasoDiProva(BaseCase):
         # go_forward()
         return self.go_forward(*args, **kwargs)
 
-    def è_testo_visto(self, *args, **kwargs):  # noqa
+    def è_testo_visto(self, *args, **kwargs):
         # is_text_visible(text, selector="html")
         return self.is_text_visible(*args, **kwargs)
 
+    def è_testo_esatto_visto(self, *args, **kwargs):
+        # is_exact_text_visible(text, selector="html")
+        return self.is_exact_text_visible(*args, **kwargs)
+
     def è_elemento_visto(self, *args, **kwargs):
         # is_element_visible(selector)
         return self.is_element_visible(*args, **kwargs)
@@ -176,6 +213,10 @@ class CasoDiProva(BaseCase):
         # wait_for_attribute(selector, attribute, value)
         return self.wait_for_attribute(*args, **kwargs)
 
+    def attendere_il_caricamento_della_pagina(self, *args, **kwargs):
+        # wait_for_ready_state_complete()
+        return self.wait_for_ready_state_complete(*args, **kwargs)
+
     def dormire(self, *args, **kwargs):
         # sleep(seconds)
         return self.sleep(*args, **kwargs)
@@ -208,6 +249,18 @@ class CasoDiProva(BaseCase):
         # js_type(selector, text)
         return self.js_type(*args, **kwargs)
 
+    def jquery_fare_clic(self, *args, **kwargs):
+        # jquery_click(selector)
+        return self.jquery_click(*args, **kwargs)
+
+    def jquery_aggiornare_testo(self, *args, **kwargs):
+        # jquery_update_text(selector, text)
+        return self.jquery_update_text(*args, **kwargs)
+
+    def jquery_digitare(self, *args, **kwargs):
+        # jquery_type(selector, text)
+        return self.jquery_type(*args, **kwargs)
+
     def controlla_html(self, *args, **kwargs):
         # inspect_html()
         return self.inspect_html(*args, **kwargs)
@@ -312,10 +365,14 @@ class CasoDiProva(BaseCase):
         # scroll_to_bottom()
         return self.scroll_to_bottom(*args, **kwargs)
 
-    def passa_il_mouse_sopra_e_fai_clic(self, *args, **kwargs):
+    def passare_il_mouse_e_fare_clic(self, *args, **kwargs):
         # hover_and_click(hover_selector, click_selector)
         return self.hover_and_click(*args, **kwargs)
 
+    def passaggio_del_mouse(self, *args, **kwargs):
+        # hover(selector)
+        return self.hover(*args, **kwargs)
+
     def è_selezionato(self, *args, **kwargs):
         # is_selected(selector)
         return self.is_selected(*args, **kwargs)
