@@ -1,11 +1,11 @@
-# Korean / 한국어 - Translations - Python 3 Only!
+# Korean / 한국어 - Translations
 from seleniumbase import BaseCase
 from seleniumbase import MasterQA
 
 
-class 셀레늄_테스트_케이스(BaseCase):  # noqa
+class 셀레늄_테스트_케이스(BaseCase):
     def __init__(self, *args, **kwargs):
-        super(셀레늄_테스트_케이스, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._language = "Korean"
 
     def 열기(self, *args, **kwargs):
@@ -24,6 +24,10 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # double_click(selector)
         return self.double_click(*args, **kwargs)
 
+    def 컨텍스트_클릭(self, *args, **kwargs):
+        # context_click(selector)
+        return self.context_click(*args, **kwargs)
+
     def 천천히_클릭(self, *args, **kwargs):
         # slow_click(selector)
         return self.slow_click(*args, **kwargs)
@@ -32,10 +36,19 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # click_if_visible(selector, by=By.CSS_SELECTOR)
         return self.click_if_visible(*args, **kwargs)
 
+    def JS_존재하는지_경우_클릭(self, *args, **kwargs):
+        # js_click_if_present(selector, by=By.CSS_SELECTOR)
+        return self.js_click_if_present(*args, **kwargs)
+
     def 링크_텍스트를_클릭합니다(self, *args, **kwargs):
         # click_link_text(link_text)
         return self.click_link_text(*args, **kwargs)
 
+    def 위치를_클릭(self, *args, **kwargs):
+        # click_with_offset(selector, x, y, by=By.CSS_SELECTOR,
+        #                   mark=None, timeout=None, center=None)
+        return self.click_with_offset(*args, **kwargs)
+
     def 텍스트를_업데이트(self, *args, **kwargs):
         # update_text(selector, text)
         return self.update_text(*args, **kwargs)
@@ -64,6 +77,14 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # assert_link_text(link_text)
         return self.assert_link_text(*args, **kwargs)
 
+    def 비어_있지_않은_텍스트_확인하는(self, *args, **kwargs):
+        # assert_non_empty_text(selector)
+        return self.assert_non_empty_text(*args, **kwargs)
+
+    def 텍스트_보이지_않는지_확인(self, *args, **kwargs):
+        # assert_text_not_visible(text, selector)
+        return self.assert_text_not_visible(*args, **kwargs)
+
     def 요소_확인(self, *args, **kwargs):
         # assert_element(selector)
         return self.assert_element(*args, **kwargs)
@@ -88,10 +109,22 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # assert_attribute(selector, attribute, value)
         return self.assert_attribute(*args, **kwargs)
 
+    def URL_확인(self, *args, **kwargs):
+        # assert_url(url)
+        return self.assert_url(*args, **kwargs)
+
+    def URL_부분_확인(self, *args, **kwargs):
+        # assert_url_contains(substring)
+        return self.assert_url_contains(*args, **kwargs)
+
     def 제목_확인(self, *args, **kwargs):
         # assert_title(title)
         return self.assert_title(*args, **kwargs)
 
+    def 제목_부분_확인(self, *args, **kwargs):
+        # assert_title_contains(substring)
+        return self.assert_title_contains(*args, **kwargs)
+
     def 제목_검색(self, *args, **kwargs):
         # get_title()
         return self.get_title(*args, **kwargs)
@@ -136,6 +169,10 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # is_text_visible(text, selector="html")
         return self.is_text_visible(*args, **kwargs)
 
+    def 정확한_텍스트가_표시됩니다(self, *args, **kwargs):
+        # is_exact_text_visible(text, selector="html")
+        return self.is_exact_text_visible(*args, **kwargs)
+
     def 요소가_표시됩니다(self, *args, **kwargs):
         # is_element_visible(selector)
         return self.is_element_visible(*args, **kwargs)
@@ -176,6 +213,10 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # wait_for_attribute(selector, attribute, value)
         return self.wait_for_attribute(*args, **kwargs)
 
+    def 페이지가_로드될_때까지_기다립니다(self, *args, **kwargs):
+        # wait_for_ready_state_complete()
+        return self.wait_for_ready_state_complete(*args, **kwargs)
+
     def 잠을(self, *args, **kwargs):
         # sleep(seconds)
         return self.sleep(*args, **kwargs)
@@ -208,6 +249,18 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # js_type(selector, text)
         return self.js_type(*args, **kwargs)
 
+    def JQUERY_클릭(self, *args, **kwargs):
+        # jquery_click(selector)
+        return self.jquery_click(*args, **kwargs)
+
+    def JQUERY_텍스트를_업데이트(self, *args, **kwargs):
+        # jquery_update_text(selector, text)
+        return self.jquery_update_text(*args, **kwargs)
+
+    def JQUERY_입력(self, *args, **kwargs):
+        # jquery_type(selector, text)
+        return self.jquery_type(*args, **kwargs)
+
     def HTML_확인(self, *args, **kwargs):
         # inspect_html()
         return self.inspect_html(*args, **kwargs)
@@ -312,10 +365,14 @@ class 셀레늄_테스트_케이스(BaseCase):  # noqa
         # scroll_to_bottom()
         return self.scroll_to_bottom(*args, **kwargs)
 
-    def 위로_마우스를_이동하고_클릭(self, *args, **kwargs):
+    def 마우스오버_및_클릭(self, *args, **kwargs):
         # hover_and_click(hover_selector, click_selector)
         return self.hover_and_click(*args, **kwargs)
 
+    def 마우스오버(self, *args, **kwargs):
+        # hover(selector)
+        return self.hover(*args, **kwargs)
+
     def 선택되어_있는지(self, *args, **kwargs):
         # is_selected(selector)
         return self.is_selected(*args, **kwargs)
