@@ -1,20 +1,13 @@
-# -*- coding: utf-8 -*-
-"""
-Converts a Selenium IDE recording that was exported as a Python WebDriver
-unittest file into SeleniumBase Python file.
-Works with Katalon Recorder scripts: http://www.katalon.com/automation-recorder
-
+"""Converts a Selenium IDE recording that was exported as a
+Python WebDriver unittest file into SeleniumBase Python file.
+Also works with exported Katalon Recorder Selenium scripts:
+    https://chrome.google.com/webstore/detail
+        /katalon-recorder-selenium/ljdobmomdgdljniojadhoplhkpialdid
 Usage:
         seleniumbase convert [PYTHON_WEBDRIVER_UNITTEST_FILE].py
-                (run from anywhere)
-    OR
-        python convert_ide.py [PYTHON_WEBDRIVER_UNITTEST_FILE].py
-                (when run from the "selenium_ide/" folder)
 Output:
         [NEW_FILE_SB].py  (adds "_SB" to the original file name)
-                          (the original file is kept intact)
-"""
-
+                          (the original file is kept intact)"""
 import codecs
 import re
 import sys
@@ -58,12 +51,12 @@ def main():
 
     seleniumbase_lines = []
     seleniumbase_lines.append("from seleniumbase import BaseCase")
-    seleniumbase_lines.append("")  # Flake8 is very specific on whitespace
+    seleniumbase_lines.append("BaseCase.main(__name__, __file__)")
+    seleniumbase_lines.append("")  # flake8 needs the whitespace
     seleniumbase_lines.append("")
 
     ide_base_url = ""
     in_test_method = False
-    has_unicode = False
     uses_keys = False
     uses_select = False
 
@@ -83,7 +76,6 @@ def main():
         # Handle utf-8 encoding if present
         data = re.findall(r"^\s*# -\*- coding: utf-8 -\*-\s*$", line)
         if data:
-            has_unicode = True
             continue
 
         # Keep SeleniumBase classes if already used in the test script
@@ -111,7 +103,6 @@ def main():
             method_name = data.group(1)
             if method_name.startswith("test_"):
                 in_test_method = True
-                seleniumbase_lines.append("")
                 seleniumbase_lines.append(data.group())
             else:
                 in_test_method = False
@@ -536,7 +527,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%sself.click(%s"%s")""" % (whitespace, uni, xpath)
             seleniumbase_lines.append(command)
             continue
@@ -553,7 +543,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%sself.submit(%s"%s")""" % (whitespace, uni, xpath)
             seleniumbase_lines.append(command)
             continue
@@ -570,7 +559,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%sself.click(%s"link=%s")""" % (
                 whitespace,
                 uni,
@@ -593,7 +581,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%s%sself.is_link_text_present(%s"%s")%s""" % (
                 whitespace,
                 pre,
@@ -618,7 +605,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%s%sself.is_element_present('[name="%s"]')%s""" % (
                 whitespace,
                 pre,
@@ -642,7 +628,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%s%sself.is_element_present("#%s")%s""" % (
                 whitespace,
                 pre,
@@ -666,7 +651,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%s%sself.is_element_present(".%s")%s""" % (
                 whitespace,
                 pre,
@@ -690,7 +674,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%s%sself.is_element_present("%s")%s""" % (
                 whitespace,
                 pre,
@@ -714,7 +697,6 @@ def main():
             uni = ""
             if '(u"' in line:
                 uni = "u"
-                has_unicode = True
             command = """%s%sself.is_element_present("%s")%s""" % (
                 whitespace,
                 pre,
@@ -896,8 +878,6 @@ def main():
         seleniumbase_lines.append(lines[line_num])
 
     seleniumbase_code = ""
-    if has_unicode and sys.version_info[0] < 3:
-        seleniumbase_code = "# -*- coding: utf-8 -*-\n"
     if uses_keys:
         seleniumbase_code += (
             "from selenium.webdriver.common.keys import Keys\n"
